pub unsafe extern "C" fn ble_eddystone_ensure_ctx_init() -> c_intExpand description
Ensure all dynamic memory required for the functioning of the eddystone beacon is allocated. No need to explicitely call the API, but still provided.
pub unsafe extern "C" fn ble_eddystone_ensure_ctx_init() -> c_intEnsure all dynamic memory required for the functioning of the eddystone beacon is allocated. No need to explicitely call the API, but still provided.