ble_gap_host_check_status

Function ble_gap_host_check_status 

pub unsafe extern "C" fn ble_gap_host_check_status() -> c_int
This API gives the current status of various stack operations

@return 0 on success; nonzero bits indicating different operations as per enum gap_status.