ble_gap_set_host_feat

Function ble_gap_set_host_feat 

pub unsafe extern "C" fn ble_gap_set_host_feat(
    bit_num: u8,
    bit_val: u8,
) -> c_int
Set or clear a bit controlled by the host in the link layer featureSet stored in the Controller

@param bit_num Bit position in the FeatureSet

@param bit_val The Host feature is disabled or enabled (0 & 1)

return 0 on success; nonzero on failure