ble_gattc_unregister_for_notification

Function ble_gattc_unregister_for_notification 

pub unsafe extern "C" fn ble_gattc_unregister_for_notification(
    conn_handle: u16,
    char_val_handle: u16,
) -> c_int
Deprecated. Use ble_gattc_unregister_notif_indicate instead.

@param conn_handle The handle of the connection with the peer device. @param char_val_handle The value handle of the characteristic to unregister from notifications and indications.

@return 0 on success, non-zero error code on failure.