ble_gatts_notify_multiple

Function ble_gatts_notify_multiple 

pub unsafe extern "C" fn ble_gatts_notify_multiple(
    conn_handle: u16,
    num_handles: usize,
    chr_val_handles: *const u16,
) -> c_int
Sends a multiple handle variable length characteristic notification. The content of the message is read from the specified characteristics. Notifications are sent in order of supplied handles. Function tries to send minimum amount of PDUs. If PDU can’t contain all of the characteristic values, multiple notifications are sent. If only one handle-value pair fits into PDU, or only one characteristic remains in the list, regular characteristic notification is sent.

If GATT client doesn’t support receiving multiple handle notifications, this will use GATT notification for each characteristic, separately.

@param conn_handle The connection over which to execute the procedure. @param num_handles The number of entries in the “chr_val_handles” array. @param chr_val_handles Array of attribute handles of the characteristics to include in the outgoing notification.

@return 0 on success; nonzero on failure.