esp_vhci_host_check_send_available

Function esp_vhci_host_check_send_available 

pub unsafe extern "C" fn esp_vhci_host_check_send_available() -> bool
@brief Check whether the Controller is ready to receive the HCI data from the Host

If the return value is True, the Host can send the HCI data to the Controller.

@note This function should be called before each esp_vhci_host_send_packet().

@return True if the Controller is ready to receive the HCI data; false otherwise