mbedtls_ssl_conf_sig_algs

Function mbedtls_ssl_conf_sig_algs 

pub unsafe extern "C" fn mbedtls_ssl_conf_sig_algs(
    conf: *mut mbedtls_ssl_config,
    sig_algs: *const u16,
)
\brief Configure allowed signature algorithms for use in TLS key exchange.

\note This only covers signature algorithms used in the key exchange. To also enforce restrictions in certificate verification refer to \c mbedtls_ssl_conf_cert_profile().

\param conf The SSL configuration to use. \param sig_algs List of allowed IANA values for TLS 1.3 signature algorithms, terminated by #MBEDTLS_TLS1_3_SIG_NONE. The list must remain available throughout the lifetime of the conf object. - For TLS 1.3, values of \c MBEDTLS_TLS1_3_SIG_XXXX should be used. - For TLS 1.2, values should be given as “(HashAlgorithm << 8) | SignatureAlgorithm”.