pub unsafe extern "C" fn nvs_flash_deinit_partition(
partition_label: *const c_char,
) -> esp_err_tExpand description
@brief Deinitialize NVS storage for the given NVS partition
@param[in] partition_label Label of the partition
@note Prefer closing all open handles with nvs_close() before deinitializing. Any handles still open for this partition are closed and freed here; using them afterwards is invalid (nvs_close() on such a handle is a no-op).
@return - ESP_OK on success - ESP_ERR_NVS_NOT_INITIALIZED if the storage for given partition was not initialized prior to this call