os_mempool_init_internal

Function os_mempool_init_internal 

pub unsafe extern "C" fn os_mempool_init_internal(
    mp: *mut os_mempool,
    blocks: u16,
    block_size: u32,
    membuf: *mut c_void,
    name: *const c_char,
    flags: u8,
) -> os_error_t
@brief Initialize a memory pool. INTERNAL USE ONLY

@param mp Pointer to a pointer to a mempool @param blocks The number of blocks in the pool @param blocks_size The size of the block, in bytes. @param membuf Pointer to memory to contain blocks. @param name Name of the pool. @param flags Mempool flags

@return os_error_t