Struct ble_hci_ev_le_subev_cs_subevent_result_continue
Source #[repr(C, packed(1))]
pub struct ble_hci_ev_le_subev_cs_subevent_result_continue {
pub subev_code: u8,
pub conn_handle: u16,
pub config_id: u8,
pub procedure_done_status: u8,
pub subevent_done_status: u8,
pub abort_reason: u8,
pub num_antenna_paths: u8,
pub num_steps_reported: u8,
pub steps: __IncompleteArrayField<cs_steps_data>,
}
conn_handle: u16
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.