Struct ble_hci_ip_rd_local_supp_codec_caps
Source #[repr(C, packed(1))]
pub struct ble_hci_ip_rd_local_supp_codec_caps {
pub codec_cap_len: u8,
pub codec_cap: __IncompleteArrayField<u8>,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.