Struct ble_hci_le_cs_test_cp
Source #[repr(C, packed(1))]
pub struct ble_hci_le_cs_test_cp {Show 22 fields
pub main_mode_type: u8,
pub sub_mode_type: u8,
pub main_mode_repetition: u8,
pub mode_0_steps: u8,
pub role: u8,
pub rtt_type: u8,
pub cs_sync_phy: u8,
pub cs_sync_antenna_selection: u8,
pub subevent_len: [u8; 3],
pub subevent_interval: u16,
pub transmit_power_level: u8,
pub t_ip1_time: u8,
pub t_ip2_time: u8,
pub t_fcs_time: u8,
pub t_pm_time: u8,
pub t_sw_time: u8,
pub tone_antenna_config_selection: u8,
pub companion_signal_enable: u8,
pub drbg_nonce: u16,
pub override_config: u16,
pub override_parameters_length: u8,
pub override_parameters_data: __IncompleteArrayField<u8>,
}
main_mode_type: u8main_mode_repetition: u8
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.