Struct ble_hci_le_set_periodic_adv_response_data
Source #[repr(C, packed(1))]
pub struct ble_hci_le_set_periodic_adv_response_data {
pub sync_handle: u16,
pub request_event: u16,
pub request_subevent: u8,
pub response_subevent: u8,
pub response_slot: u8,
pub response_data_length: u8,
pub response_data: __IncompleteArrayField<u8>,
}
sync_handle: u16
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.