esp_bt_controller_config_t

Struct esp_bt_controller_config_t 

#[repr(C)]
pub struct esp_bt_controller_config_t {
Show 30 fields pub controller_task_stack_size: u16, pub controller_task_prio: u8, pub hci_uart_no: u8, pub hci_uart_baudrate: u32, pub scan_duplicate_mode: u8, pub scan_duplicate_type: u8, pub normal_adv_size: u16, pub mesh_adv_size: u16, pub send_adv_reserved_size: u16, pub controller_debug_flag: u32, pub mode: u8, pub ble_max_conn: u8, pub bt_max_acl_conn: u8, pub bt_sco_datapath: u8, pub auto_latency: bool, pub bt_legacy_auth_vs_evt: bool, pub bt_max_sync_conn: u8, pub ble_sca: u8, pub pcm_role: u8, pub pcm_polar: u8, pub pcm_fsyncshp: u8, pub hli: bool, pub enc_key_sz_min: u8, pub dup_list_refresh_period: u16, pub ble_scan_backoff: bool, pub ble_llcp_disc_flag: u8, pub ble_aa_check: bool, pub ble_chan_ass_en: u8, pub ble_ping_en: u8, pub magic: u32,
}
@brief Bluetooth Controller config options @note 1. For parameters configurable through menuconfig, it is recommended to adjust them via the menuconfig interface. Please refer to menuconfig for details on the range and default values. 2. It is not recommended to modify the values for parameters which are not configurable through menuconfig.

Fields

controller_task_stack_size: u16

< Bluetooth Controller task stack size in bytes

controller_task_prio: u8

< Bluetooth Controller task priority

hci_uart_no: u8

< UART number as HCI I/O interface. Configurable in menuconfig.

  • 1 - URAT 1 (default)
  • 2 - URAT 2
hci_uart_baudrate: u32

< UART baudrate. Configurable in menuconfig.

  • Range: 115200 - 921600
  • Default: 921600
scan_duplicate_mode: u8

< Scan duplicate filtering mode. Configurable in menuconfig.

  • 0 - Normal scan duplicate filtering mode (default)
  • 1 - Special scan duplicate filtering mode for BLE Mesh
scan_duplicate_type: u8

< Scan duplicate filtering type. If scan_duplicate_mode is set to 1, this parameter will be ignored. Configurable in menuconfig.

  • 0 - Filter scan duplicates by device address only (default)
  • 1 - Filter scan duplicates by advertising data only, even if they originate from different devices.
  • 2 - Filter scan duplicated by device address and advertising data.
normal_adv_size: u16

< Maximum number of devices in scan duplicate filtering list. Configurable in menuconfig

  • Range: 10 - 1000
  • Default: 100
mesh_adv_size: u16

< Maximum number of Mesh advertising packets in scan duplicate filtering list. Configurable in menuconfig

  • Range: 10 - 1000
  • Default: 100
send_adv_reserved_size: u16

< Controller minimum memory value in bytes. Internal use only

controller_debug_flag: u32

< Controller debug log flag. Internal use only

mode: u8

< Controller mode. Configurable in menuconfig

  • 1 - BLE mode
  • 2 - Classic Bluetooth mode
  • 3 - Dual mode
  • 4 - Others: Invalid
ble_max_conn: u8

< Maximum number of BLE connections. Configurable in menuconfig

  • Range: 1 - 9
  • Default: 3
bt_max_acl_conn: u8

< Maximum number of BR/EDR ACL connections. Configurable in menuconfig

  • Range: 1 - 7
  • Default: 2
bt_sco_datapath: u8

< SCO data path. Configurable in menuconfig

  • 0 - HCI module (default)
  • 1 - PCM module
auto_latency: bool

< True if BLE auto latency is enabled, used to enhance Classic Bluetooth performance in the Dual mode; false otherwise (default). Configurable in menuconfig

bt_legacy_auth_vs_evt: bool

< True if BR/EDR Legacy Authentication Vendor Specific Event is enabled (default in the classic bluetooth or Dual mode), which is required to protect from BIAS attack; false otherwise. Configurable in menuconfig

bt_max_sync_conn: u8

< Maximum number of BR/EDR synchronous connections. Configurable in menuconfig

  • Range: 0 - 3
  • Default: 0
ble_sca: u8

< BLE low power crystal accuracy index. Configurable in menuconfig

  • 0 - BTDM_BLE_DEFAULT_SCA_500PPM
  • 1 - BTDM_BLE_DEFAULT_SCA_250PPM (default)
pcm_role: u8

< PCM role. Configurable in menuconfig

  • 0 - PCM master (default)
  • 1 - PCM slave (default)
pcm_polar: u8

< PCM polarity (falling clk edge & rising clk edge). Configurable in menuconfig

  • 0 - Falling Edge (default)
  • 1 - Rising Edge
pcm_fsyncshp: u8

< Physical shape of the PCM Frame Synchronization signal. Configurable in menuconfig

  • 0 - Stereo Mode (default)
  • 1 - Mono Mode 1
  • 2 - Mono Mode 2
hli: bool

< True if using high-level (level 4) interrupt (default); false otherwise. Configurable in menuconfig

enc_key_sz_min: u8

< Minimum size of the encryption key

  • Range: 7 - 16
  • Default: 7
dup_list_refresh_period: u16

< Scan duplicate filtering list refresh period in seconds. Configurable in menuconfig

  • Range: 0 - 100 seconds
  • Default: 0 second
ble_scan_backoff: bool

< True if BLE scan backoff is enabled; false otherwise (default). Configurable in menuconfig

ble_llcp_disc_flag: u8

< Flag indicating whether the Controller disconnects after Instant Passed (0x28) error occurs. Configurable in menuconfig.

  • The Controller does not disconnect after Instant Passed (0x28) by default.
ble_aa_check: bool

< True if adds a verification step for the Access Address within the CONNECT_IND PDU; false otherwise (default). Configurable in menuconfig

ble_chan_ass_en: u8

< True if BLE channel assessment is enabled (default), false otherwise. Configurable in menuconfig

ble_ping_en: u8

< True if BLE ping procedure is enabled (default), false otherwise. Configurable in menuconfig

magic: u32

< Magic number