#[repr(C)]pub struct mbedtls_lmots_parameters_t {
pub private_I_key_identifier: [c_uchar; 16],
pub private_q_leaf_identifier: [c_uchar; 4],
pub private_type: mbedtls_lmots_algorithm_type_t,
}Expand description
LMOTS parameters structure.
This contains the metadata associated with an LMOTS key, detailing the algorithm type, the key ID, and the leaf identifier should be key be part of a LMS key.
Fields
private_I_key_identifier: [c_uchar; 16]private_q_leaf_identifier: [c_uchar; 4]private_type: mbedtls_lmots_algorithm_type_tTrait Implementations
Sourceimpl Clone for mbedtls_lmots_parameters_t
impl Clone for mbedtls_lmots_parameters_t
Sourcefn clone(&self) -> mbedtls_lmots_parameters_t
fn clone(&self) -> mbedtls_lmots_parameters_t
Returns a duplicate of the value. Read more
1.0.0 (const: unstable)fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for mbedtls_lmots_parameters_t
impl Debug for mbedtls_lmots_parameters_t
Sourceimpl Default for mbedtls_lmots_parameters_t
impl Default for mbedtls_lmots_parameters_t
impl Copy for mbedtls_lmots_parameters_t