Struct periodic_adv_response
Source #[repr(C, packed(1))]
pub struct periodic_adv_response {
pub tx_power: i8,
pub rssi: i8,
pub cte_type: u8,
pub response_slot: u8,
pub data_status: u8,
pub data_length: u8,
pub data: __IncompleteArrayField<u8>,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.