Struct periodic_adv_subevents
Source #[repr(C, packed(1))]
pub struct periodic_adv_subevents {
pub subevent: u8,
pub response_slot_start: u8,
pub response_slot_count: u8,
pub subevent_data_length: u8,
pub subevent_data: __IncompleteArrayField<u8>,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.