wifi_auth_mode_t

Type Alias wifi_auth_mode_t 

pub type wifi_auth_mode_t = c_uint;
@brief Wi-Fi authmode type Strength of authmodes Personal Networks : OPEN < WEP < WPA_PSK < OWE < WPA2_PSK = WPA_WPA2_PSK < WAPI_PSK < WPA3_PSK = WPA2_WPA3_PSK = DPP Enterprise Networks : WIFI_AUTH_WPA_ENTERPRISE < WIFI_AUTH_WPA2_ENTERPRISE < WIFI_AUTH_WPA3_ENT_192

@note WIFI_AUTH_UNKNOWN indicates an Access Point with invalid or unparseable security configuration detected during scan parsing.