pub unsafe extern "C" fn nvs_flash_deinit() -> esp_err_tExpand description
@brief Deinitialize NVS storage for the default NVS partition
Default NVS partition is the partition with “nvs” label in the partition table.
@note Prefer closing all open handles with nvs_close() before deinitializing. Any handles still open for this partition are closed and freed here; using them afterwards is invalid (nvs_close() on such a handle is a no-op).
@return - ESP_OK on success (storage was deinitialized) - ESP_ERR_NVS_NOT_INITIALIZED if the storage was not initialized prior to this call