pub type os_mempool_get_fn = Option<unsafe extern "C" fn(ome: *mut os_mempool_ext, arg: *mut c_void) -> *mut c_void>;Expand description
Block get callback function. If configured, this callback gets executed whenever a block is fetched from the corresponding extended mempool.
@param ome The extended mempool that a block is being fetched. @param arg Optional argument configured along with the callback.
@return void * pointer of block, return NULL if get failed
Aliased Type
pub enum os_mempool_get_fn {
None,
Some(unsafe extern "C" fn(*mut os_mempool_ext, *mut c_void) -> *mut c_void),
}Variants
None
No value.
Some(unsafe extern "C" fn(*mut os_mempool_ext, *mut c_void) -> *mut c_void)
Some value of type T.